@@ -9,14 +9,14 @@ class ImageEntry(EntryBlock):
 
     def mock(self, force_file=None, size='m', *args, **kwargs):
         if 'theme' in kwargs:
-            img = self.mocker.IMG_CONTENT_WIDTH_LIGHT if kwargs['theme'] == constants.THEME_LIGHT else self.mocker.IMG_CONTENT_WIDTH_SPACE
+            img = self.IMG_CONTENT_WIDTH_LIGHT if kwargs['theme'] == constants.THEME_LIGHT else self.IMG_CONTENT_WIDTH_SPACE
         else:
-            img = self.mocker.IMG_CONTENT_HEIGHT_SPACE
+            img = self.IMG_CONTENT_HEIGHT_SPACE
         self.mock_data.update({
             'type': 'image',
             'value': {
                 'image': {
-                    'file': self.mocker.file(img if not force_file else force_file).id,
+                    'file': self.file(img if not force_file else force_file).id,
                     'size': size
                 }
             }
