@@ -170,7 +170,7 @@ class AGenericPage(Page):
 
     def get_context(self, request, *args, **kwargs):
         context = super(AGenericPage, self).get_context(request)
-        context['debug'] = str(settings.DEBUG)
+        context['debug'] = settings.DEBUG
         context['icons'] = IconSnippet.get_context()
         context['studio'] = {
             'name': constants.STUDIO_NAME,
