@@ -223,7 +223,19 @@ class ABlogIndexPage(AmpMixin, WagtailPageBakeryModel, GenericPage):
             blogs = paginator.page(paginator.num_pages)
         context = super(ABlogIndexPage, self).get_context(request)
         context['blogs'] = blogs
-        context['tags'] = Tag.objects.filter(cms_blogpagetag_items__isnull=False).distinct()
+
+        # FIXME start: tags must be have wagtail `Site`
+
+        tags_exist = Tag.objects.filter(cms_blogpagetag_items__isnull=False).distinct()
+        tags = []
+        for tag_item in tags_exist:
+            site = tag_item.cms_blogpagetag_items.first().content_object.get_site()
+            if site.id == request.site.id:
+                tags.append(tag_item)
+        context['tags'] = tags
+
+        # FIXME end
+
         context['current_tag'] = tag
         return context
 
