@@ -1,4 +1,4 @@
-from webspace.cms.bakery.abstract import WagtailPageBakeryModel
+from webspace.bakery.abstract import WagtailPageBakeryModel
 from webspace.cms import constants
 from webspace.cms.amp.mixins import AmpMixin
 from webspace.loader import get_model
