@@ -133,17 +133,17 @@ const Aside = {
 
     if (accordion) {
       document.addEventListener('click', (e) => {
-        accordion.style.left = '-100%';
+        accordion.style.right = '-100%';
       });
 
       accordionOpen.addEventListener('click', (e) => {
         e.stopPropagation();
-        accordion.style.left = '0';
+        accordion.style.right = '0';
       });
 
       accordionClose.addEventListener('click', (e) => {
         e.stopPropagation();
-        accordion.style.left = '-100%';
+        accordion.style.right = '-100%';
       });
     }
   },
